@@ -881,7 +881,12 @@ int iso15693_get_system_information(iso15693_t* iso15693, rfid_transponder_t* tr
 	}
 	db = iso15693->system_information;
 
-	if((error = db->open(db, 0, ISO15693_GET_SYSTEM_INFORMATION_FILE, 0, DB_BTREE, DB_RDONLY|DB_THREAD, 0))) {
+#if DB_VERSION_MAJOR >= 4 && DB_VERSION_MINOR >= 1
+	if((error = db->open(db, 0, ISO15693_GET_SYSTEM_INFORMATION_FILE, 0, DB_BTREE, DB_RDONLY|DB_THREAD, 0)))
+#else /* DB_VERSION_MAJOR >= 4 && DB_VERSION_MINOR >= 1 */
+	if((error = db->open(db, 0, ISO15693_GET_SYSTEM_INFORMATION_FILE, DB_BTREE, DB_RDONLY|DB_THREAD, 0)))
+#endif /* DB_VERSION_MAJOR >= 4 && DB_VERSION_MINOR >= 1 */
+	{
 	  if(iso15693->verbose) fprintf(stderr, "db->open(%s): %s\n", ISO15693_GET_SYSTEM_INFORMATION_FILE, db_strerror(error));
 	  db->close(db, 0);
 	  iso15693->system_information = 0;
