@@ -317,8 +317,9 @@ static int test_get_system_information(context_t* context)
   }
 
   if(context->verbose > 1) {
+    char* description;
     printf("==============================\nget_system_information (addressed)\n");
-    char* description = reader->transponder_describe_f(reader, transponder);
+    description = reader->transponder_describe_f(reader, transponder);
     printf("==============================\n%s", description);
     free(description);
   }
@@ -341,8 +342,9 @@ static int test_get_system_information(context_t* context)
   }
 
   if(context->verbose > 1) {
+    char* description;
     printf("==============================\nget_system_information (non addressed)\n");
-    char* description = reader->transponder_describe_f(reader, transponder);
+    description = reader->transponder_describe_f(reader, transponder);
     printf("==============================\n%s", description);
     free(description);
   }
@@ -386,8 +388,9 @@ static int test_transponder_present_driver(context_t* context)
   }
 
   if(context->verbose > 1) {
+    char* description;
     printf("==============================\ntransponder_present\n");
-    char* description = reader->transponder_describe_f(reader, transponder);
+    description = reader->transponder_describe_f(reader, transponder);
     printf("==============================\n%s", description);
     free(description);
   }
@@ -414,7 +417,7 @@ static int test_transponder_present_driver(context_t* context)
 static int test_write_single_block(context_t* context)
 {
   rfid_block_t block;
-  char storage[ISO15693_BLOCK_SIZE_MAX];
+  u_int8_t storage[ISO15693_BLOCK_SIZE_MAX];
   iso15693_t* iso15693 = context->iso15693;
   rfid_transponder_t* transponder = context->transponder;
   int retval = -1;
@@ -454,13 +457,15 @@ static int test_write_multiple_block(context_t* context)
   iso15693_t* iso15693 = context->iso15693;
   rfid_transponder_t* transponder = context->transponder;
   int blocks_length = 2;
-  rfid_block_t blocks[blocks_length];
+  rfid_block_t* blocks;
   u_int8_t* pointer = transponder->data;
 
   alarm(context->timeout);
 
   memset(transponder->data, 'A', RFID_TRANSPONDER_DATA_SIZE);
 
+  blocks = (rfid_block_t*)malloc(sizeof(rfid_block_t) * blocks_length);
+
   for(i = 0; i < blocks_length; i++) {
     blocks[i].data = pointer;
     pointer += transponder->bytes_per_block;
@@ -478,6 +483,8 @@ static int test_write_multiple_block(context_t* context)
 
  err:
 
+  free(blocks);
+
   alarm(0);
 
   show_result("write_multiple_blocks");
@@ -488,7 +495,7 @@ static int test_write_multiple_block(context_t* context)
 static int test_read_single_block(context_t* context)
 {
   rfid_block_t block;
-  char storage[ISO15693_BLOCK_SIZE_MAX];
+  u_int8_t storage[ISO15693_BLOCK_SIZE_MAX];
   iso15693_t* iso15693 = context->iso15693;
   rfid_transponder_t* transponder = context->transponder;
   int retval = -1;
@@ -533,11 +540,13 @@ static int test_read_multiple_blocks(context_t* context)
   iso15693_t* iso15693 = context->iso15693;
   rfid_transponder_t* transponder = context->transponder;
   int blocks_length = transponder->blocks;
-  rfid_block_t blocks[blocks_length];
+  rfid_block_t* blocks;
   u_int8_t* pointer = transponder->data;
 
   alarm(context->timeout);
 
+  blocks = (rfid_block_t*)malloc(sizeof(rfid_block_t) * blocks_length);
+
   for(i = 0; i < blocks_length; i++) {
     blocks[i].data = pointer;
     pointer += transponder->bytes_per_block;
@@ -564,6 +573,8 @@ static int test_read_multiple_blocks(context_t* context)
 
   alarm(0);
 
+  free(blocks);
+
   show_result("read_multiple_blocks");
 
   return retval;
@@ -576,7 +587,7 @@ static int test_lock_block(context_t* context)
   iso15693_t* iso15693 = context->iso15693;
   rfid_transponder_t* transponder = context->transponder;
   rfid_block_t block;
-  char storage[ISO15693_BLOCK_SIZE_MAX];
+  u_int8_t storage[ISO15693_BLOCK_SIZE_MAX];
 
   if(!context->destructive) {
     if(context->verbose) fprintf(stderr, "lock_block : SKIP (destructive)\n");
@@ -1041,10 +1052,7 @@ int main(int argc, char** argv)
   if(argc > 2)
     device = argv[2];
 
-  if(signal(SIGALRM, timeout_f) < 0) {
-    perror("signal(SIGALRM)");
-    return -1;
-  }
+  signal(SIGALRM, timeout_f);
 
   memset(&context, '\0', sizeof(context_t));
   if(argc > 3)
